Particular Solution
Description: 40xy' -ln(x^8) = 0 Initial Condition: y(1)=31 Work: 40x (dy/dx) - ln(x^8) = 0 40x(dy/dx) = ln (x^8) dy/dx = ln(x^8) / 40x Sdy = Sln(x^8) / 40x And
Keywords: Particular,Solution,solution

- Register
- Save?

Results 1 to 7 of 7

# Thread: Particular Solution

- ###### LinkBack

  - LinkBack URL
  - About LinkBacks

- ###### Thread Tools

  - Show Printable Version
  - Subscribe to this Thread…

- ###### Display

  - Linear Mode
  - Switch to Hybrid Mode
  - Switch to Threaded Mode

1. Jan 23rd 2011, 08:29 AM #1
   BooGTS
   Newbie

   Joined
     Feb 2009
   Posts
     21

   ## Particular Solution

   > 40xy' -ln(x^8) = 0
   > Initial Condition: y(1)=31
   > Work:
   > 40x (dy/dx) - ln(x^8) = 0
   > 40x(dy/dx) = ln (x^8)
   > dy/dx = ln(x^8) / 40x
   > Sdy = Sln(x^8) / 40x
   > And then...stuck (if its even right thus far)

   > Follow Math Help Forum on Facebook and Google+

2. Jan 23rd 2011, 08:35 AM #2
   Chris L T521
   Rhymes with Orange

   Joined
     May 2008
   From
     Chicago, IL
   Posts
     2,844
   Thanks
     5

   > Originally Posted by BooGTS
   > 40xy' -ln(x^8) = 0
   > Initial Condition: y(1)=31
   > Work:
   > 40x (dy/dx) - ln(x^8) = 0
   > 40x(dy/dx) = ln (x^8)
   > dy/dx = ln(x^8) / 40x
   > Sdy = Sln(x^8) / 40x
   > And then...stuck (if its even right thus far)
   > Hint: $\displaystyle \ln(x^8)=8 \ln x$. Then the integral on the RHS becomes $\displaystyle \displaystyle\frac{1}{5}\int\frac{\ln x}{x}\,dx$.
   > Do you know how to proceed?
   > (And yes, everything is right so far. )

   > Follow Math Help Forum on Facebook and Google+

3. Jan 23rd 2011, 08:36 AM #3
   chisigma
   MHF Contributor

   Joined
     Mar 2009
   From
     near Piacenza (Italy)
   Posts
     2,162
   Thanks
     6

   > Because is $\displaystyle \ln x^{8} = 8\ \ln x$ the DE becomes...
   > $\displaystyle \displaystyle y^{'} = \frac{\ln x}{5 x}$ (1)
   > ... where the variables are separated so that the solution is immediate...
   > Kind regards
   > $\displaystyle \chi$ $\displaystyle \sigma$

   > Follow Math Help Forum on Facebook and Google+

4. Jan 23rd 2011, 08:49 AM #4
   HallsofIvy
   MHF Contributor

   Joined
     Apr 2005
   Posts
     19,630
   Thanks
     2955

   > Originally Posted by Chris L T521
   > Hint: $\displaystyle \ln(x^8)=8 \ln x$. Then the integral on the RHS becomes $\displaystyle \displaystyle\frac{1}{5}\int\frac{\ln x}{x}\,dx$.
   > Do you know how to proceed?
   > (And yes, everything is right so far. )
   > If you are concerned about how to do that integral, let u= ln(x).

   > Follow Math Help Forum on Facebook and Google+

5. Jan 23rd 2011, 12:42 PM #5
   BooGTS
   Newbie

   Joined
     Feb 2009
   Posts
     21

   > Still not doing this right I don't think:
   > y= 1/5 (lnxdx)/x
   > = 1/5 u du
   > = 1/5 u^2/2
   > = 1/10 lnx^2

   > Follow Math Help Forum on Facebook and Google+

6. Jan 23rd 2011, 01:58 PM #6
   skeeter
   MHF Contributor

   Joined
     Jun 2008
   From
     North Texas
   Posts
     16,216
   Thanks
     3700

   > Originally Posted by BooGTS
   > Still not doing this right I don't think:
   > y= 1/5 (lnxdx)/x
   > = 1/5 u du
   > = 1/5 u^2/2
   > = 1/10 lnx^2
   > note the difference between $\displaystyle \ln{x^2}$ and $\displaystyle (\ln{x})^2$ ...
   > the correct antiderivative is
   > $\displaystyle \displaystyle \frac{(\ln{x})^2}{10} + C$

   > Follow Math Help Forum on Facebook and Google+

7. Jan 23rd 2011, 02:42 PM #7
   BooGTS
   Newbie

   Joined
     Feb 2009
   Posts
     21

   > Yeah, big difference. Thanks to all (and on the site if I can figure out how)

   > Follow Math Help Forum on Facebook and Google+

« Hyperbolic Inverse Equation | Tide removing sand from a beach »

#### Similar Math Help Forum Discussions

1. ###### For what value of k.. no solution / unique solution / infinitely many solutions

   Posted in the Advanced Algebra Forum
   Replies: 1
   Last Post: Sep 23rd 2011, 03:39 AM

2. ###### General Solution of a differential solution

   Posted in the Differential Equations Forum
   Replies: 4
   Last Post: Sep 11th 2010, 02:49 AM

3. ###### Systems of linear equations - no solution, unique solution, infinite solutions

   Posted in the Algebra Forum
   Replies: 1
   Last Post: Mar 24th 2010, 12:14 AM

4. ###### Find solutions such that A: no solution, B: Unique solution C: Infinitely many

   Posted in the Advanced Algebra Forum
   Replies: 2
   Last Post: Sep 7th 2009, 02:01 PM

5. ###### find the general solution when 1 solution is given

   Posted in the Differential Equations Forum
   Replies: 4
   Last Post: Mar 4th 2009, 09:09 PM

#### Search Tags

solution

View Tag Cloud